Exception: Hook0::Runtime::DecodeError
- Inherits:
-
StandardError
- Object
- StandardError
- Hook0::Runtime::DecodeError
- Defined in:
- lib/hook0/runtime.rb
Overview
What the API answered is not what it declares it answers.
What the API answered is not what it declares it answers.